==> raqdevil-0.9.6.tar.gz: raqdevil-0.9.6/cce-ui-1.0/web/base/swupdate/splashSoftware.php <==
<?php
// Copyright 2000, 2001 Sun Microsystems, Inc.  All rights reserved.
// $Id: splashSoftware.php,v 1.12 2005/10/20 22:57:23 dodell Exp $

include_once("ServerScriptHelper.php");
include_once("base/swupdate/updateLib.php");

$serverScriptHelper = new ServerScriptHelper();
$cceClient = $serverScriptHelper->getCceClient();
$factory = $serverScriptHelper->getHtmlComponentFactory("base-swupdate");
$i18n = $serverScriptHelper->getI18n("base-swupdate");

if (isset($_GET['check']))
	require_once 'update.php';

$page = $factory->getPage();

$checkNowButton = $factory->getButton("/base/swupdate/splashSoftware.php?check=1", "checkNowUpdate");

$serialUpdates = base64_encode(serialize($update_a));
$manualInstallButton = $factory->getButton("/base/swupdate/updateHandler.php?updates=$serialUpdates", "Install Now");

// build the scroll list
$scrollList = $factory->getScrollList("availableListUpdates", array("nameField", "versionField", "New Version", "descriptionField", "MD5 Sum", "Filesize"));
$scrollList->setAlignments(array("center", "left", "left", "left", "left", "center"));
//$scrollList->setColumnWidths(array("", "25%", "25%", "25%", "45%", "5%"));
$scrollList->setSortEnabled(0);
$scrollList->processErrors($serverScriptHelper->getErrors());

$pageLength = $scrollList->getLength();
$start = $scrollList->getPageIndex()*$pageLength;

for($i = 0; $i < count($update_a); $i++) {
	$description = $update_a[$i][0];
	$packageName = $update_a[$i][1];
	$version = $update_a[$i][2];
	$versionNew = $update_a[$i][3];
	$md5 = $update_a[$i][5];
	$fsize = round(($update_a[$i][6] / 1024), 1) . 'K'; 

  $scrollList->addEntry(array(
    //$factory->getStatusSignal($new),
    $factory->getTextField("", $packageName, "r"),
    $factory->getTextField("", $version, "r"),
    $factory->getTextField("", $versionNew, "r"),
    $factory->getTextField("", $description, "r"),
    $factory->getTextField("", $md5, "r"),
    $factory->getTextField("", $fsize, "r"),
  ));
}

print($page->toHeaderHtml());

$serverScriptHelper->destructor();
?>
<TABLE>
  <TR>
<?php
if (count($update_a) > 0) {
?>
    <TD COLSPAN=2>
<?php print($manualInstallButton->toHtml()); ?>
    </TD>
<?php } else { ?>
    <TD COLSPAN=2>
<?php print($checkNowButton->toHtml()); ?>
    </TD>
<?php } ?>
  </TR>
</TABLE>
<BR>

<?php if (isset($_GET['check'])) { print($scrollList->toHtml()); } ?>
<?php print($page->toFooterHtml());
/*
Copyright (c) 2003 Sun Microsystems, Inc. All  Rights Reserved.

Redistribution and use in source and binary forms, with or without modification, 
are permitted provided that the following conditions are met:

-Redistribution of source code must retain the above copyright notice, this  list of conditions and the following disclaimer.

-Redistribution in binary form must reproduce the above copyright notice, 
this list of conditions and the following disclaimer in the documentation and/or 
other materials provided with the distribution.

Neither the name of Sun Microsystems, Inc. or the names of contributors may 
be used to endorse or promote products derived from this software without 
specific prior written permission.

This software is provided "AS IS," without a warranty of any kind. ALL EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE HEREBY EXCLUDED. SUN MICROSYSTEMS, INC. ("SUN") AND ITS LICENSORS SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES. IN NO EVENT WILL SUN OR ITS LICENSORS BE LIABLE FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT, INDIRECT, SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF THE USE OF OR INABILITY TO USE THIS SOFTWARE, EVEN IF SUN HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.

You acknowledge that  this software is not designed or intended for use in the design, construction, operation or maintenance of any nuclear facility.
*/
?>

==> raqdevil-1.0.tar.gz: raqdevil-1.0/cce-ui-1.0/web/base/swupdate/splashSoftware.php <==
<?php
// Copyright 2000, 2001 Sun Microsystems, Inc.  All rights reserved.
// $Id: splashSoftware.php,v 1.15 2005/12/07 00:04:53 dodell Exp $

include_once("ServerScriptHelper.php");
include_once("base/swupdate/updateLib.php");

$serverScriptHelper = new ServerScriptHelper();
$cceClient = $serverScriptHelper->getCceClient();
$factory = $serverScriptHelper->getHtmlComponentFactory("base-swupdate");
$i18n = $serverScriptHelper->getI18n("base-swupdate");

if (isset($_GET['check']))
	require_once 'update.php';

$page = $factory->getPage();

$checkNowButton = $factory->getButton("/base/swupdate/splashSoftware.php?check=1", "checkNowUpdate");

$serialUpdates = rawurlencode(serialize($update_a));
$manualInstallButton = $factory->getButton("/base/swupdate/updateHandler.php?updates=$serialUpdates", "Install Now");

// build the scroll list
$scrollList = $factory->getScrollList("availableListUpdates", array("nameField", "versionField", "New Version", "descriptionField", "MD5 Sum", "Filesize"));
$scrollList->setAlignments(array("center", "left", "left", "left", "left", "center"));
//$scrollList->setColumnWidths(array("", "25%", "25%", "25%", "45%", "5%"));
$scrollList->setSortEnabled(0);
$scrollList->processErrors($serverScriptHelper->getErrors());

$pageLength = $scrollList->getLength();
$start = $scrollList->getPageIndex()*$pageLength;

for($i = 0; $i < count($update_a); $i++) {
	$description = $update_a[$i][0];
	$packageName = $update_a[$i][1];
	$version = $update_a[$i][2];
	$versionNew = $update_a[$i][3];
	$md5 = $update_a[$i][5];
	$fsize = round(($update_a[$i][6] / 1024), 1) . 'K'; 

  $scrollList->addEntry(array(
    //$factory->getStatusSignal($new),
    $factory->getTextField("", $packageName, "r"),
    $factory->getTextField("", $version, "r"),
    $factory->getTextField("", $versionNew, "r"),
    $factory->getTextField("", $description, "r"),
    $factory->getTextField("", $md5, "r"),
    $factory->getTextField("", $fsize, "r"),
  ));
}

print($page->toHeaderHtml());

$serverScriptHelper->destructor();
?>
<table><tr><td>
UplinQ dynamically updates your running RAQdevil system. As with any updates, we
recommend doing a complete backup of all critical data before commencing with
the upgrade procedure.<br><br>
</td></tr></table>
<TABLE>
  <TR>
<?php
if (count($update_a) > 0) {
?>
    <TD COLSPAN=2>
<?php print($manualInstallButton->toHtml()); ?>
    </TD>
<?php } else { ?>
    <TD COLSPAN=2>
<?php print($checkNowButton->toHtml()); ?>
    </TD>
<?php } ?>
  </TR>
</TABLE>
<BR>

<?php if (isset($_GET['check'])) { print($scrollList->toHtml()); } ?>
<?php print($page->toFooterHtml());
/*
Copyright (c) 2003 Sun Microsystems, Inc. All  Rights Reserved.

Redistribution and use in source and binary forms, with or without modification, 
are permitted provided that the following conditions are met:

-Redistribution of source code must retain the above copyright notice, this  list of conditions and the following disclaimer.

-Redistribution in binary form must reproduce the above copyright notice, 
this list of conditions and the following disclaimer in the documentation and/or 
other materials provided with the distribution.

Neither the name of Sun Microsystems, Inc. or the names of contributors may 
be used to endorse or promote products derived from this software without 
specific prior written permission.

This software is provided "AS IS," without a warranty of any kind. ALL EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE HEREBY EXCLUDED. SUN MICROSYSTEMS, INC. ("SUN") AND ITS LICENSORS SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES. IN NO EVENT WILL SUN OR ITS LICENSORS BE LIABLE FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT, INDIRECT, SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF THE USE OF OR INABILITY TO USE THIS SOFTWARE, EVEN IF SUN HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.

You acknowledge that  this software is not designed or intended for use in the design, construction, operation or maintenance of any nuclear facility.
*/
?>
